@@ -1,7 +1,7 @@
 checkConnection <- function(details) {
-  if ( Sys.getpid() != details[["pid"]] ) {
+  if ( Sys.getpid() != details[["pidOfR"]] ) {
     close.rscalaBridge(details)
-    stop("Each process should have its own rscala bridge.  Closing this bridge.")
+    stop("Each process should have its own Scala bridge.  Closing this bridge.")
   }
   if ( details[['closed']] ) stop("Bridge is closed.")
 }
